==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/ka_GE.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "წვდომის მინიჭება",
    "Error configuring OAuth1" : "OAuth1-ის კონფიგურირებისას წარმოიშვა შეცდომა",
    "Please provide a valid app key and secret." : "გთხოვთ უზრუნველყოთ სწორი აპლიკაციის გასაღები და საიდუმლო.",
    "Error configuring OAuth2" : "OAuth2-ის კონფიგურირებისას წარმოიშვა შეცდომა",
    "Generate keys" : "გასაღებების გენერირება",
    "Error generating key pair" : "გასაღების წყვილის გენერირებისას წარმოიშვა შეცდომა",
    "Storage with ID \"%d\" not found" : "საცავი ID-ით \"%d\" ვერ იქნა ნაპოვნი",
    "Invalid backend or authentication mechanism class" : "არასწორი ბექენდი ან აუტენტიფიკაციის მექანიზმის კლასი",
    "Invalid mount point" : "არასწორი მონტაჟის წერტილი",
    "Objectstore forbidden" : "ობიექტსტორი აკრძალულია",
    "Invalid storage backend \"%s\"" : "არასწორი საცავის ბექენდი \"%s\"",
    "Not permitted to use backend \"%s\"" : "ბექენის \"%s\" გამოყენება არაა ნებადართული",
    "Not permitted to use authentication mechanism \"%s\"" : "აუტენტიკაციის მექანიზმის \"%s\"-ს გამოყენება არაა ნებადართული",
    "Unsatisfied backend parameters" : "ბექენდის პარამეტრები არადამაკმაყოფილებელია",
    "Unsatisfied authentication mechanism parameters" : "აუტენტიფიკაციის მექნიზმის პარამეტრები არადამაკმაყოფილებელია",
    "Insufficient data: %s" : "არასაკმარისი მონაცემები: %s",
    "%s" : "%s",
    "Access key" : "წვდომის გასაღები",
    "Secret key" : "საიდუმლო გასაღები",
    "Builtin" : "ჩაშენებული",
    "None" : "არც ერთი",
    "OAuth1" : "OAuth1",
    "App key" : "აპლიკაციის გასაღები",
    "App secret" : "აპლიკაციის საიდუმლო",
    "OAuth2" : "OAuth2",
    "Client ID" : "კლიენტის ID",
    "Client secret" : "კლიენტის საიდუმლო",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "ავტორიზაცია",
    "Password" : "პაროლი",
    "Tenant name" : "მოიჯარის სახელი",
    "Identity endpoint URL" : "იდენტობის საბოლოო-წერტილის URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "დომენი",
    "Rackspace" : "Rackspace-ი",
    "API key" : "API გასაღები",
    "Global credentials" : "გლობალური მონაცემები",
    "Log-in credentials, save in database" : "ლოგინის მონაცემები, შენახვა მონაცემთა ბაზაში",
    "Log-in credentials, save in session" : "ლოგინის მონაცემები, შენახვა სესიაში",
    "RSA public key" : "RSA ღია გასაღები",
    "Public key" : "ღია გასაღები",
    "Amazon S3" : "Amazon S3-ი",
    "Bucket" : "ხაპია",
    "Hostname" : "ჰოსტი",
    "Port" : "პორტი",
    "Region" : "რეგიონი",
    "Enable SSL" : "SSL-ის ამოქმედება",
    "Enable Path Style" : "ბილიკის სტილის ამოქმედება",
    "Legacy (v2) authentication" : "ლეგატი (ვ2) აუტენტიფიკაცია",
    "WebDAV" : "WebDAV-ი",
    "URL" : "URL",
    "Remote subfolder" : "დისტანციური ქვე-დირექტორია",
    "Secure https://" : "დაცული https://",
    "FTP" : "FTP",
    "Host" : "ჰოსტი",
    "Secure ftps://" : "დაცული ftps://",
    "Local" : "ლოკალური",
    "Location" : "ადგილმდებარეობა",
    "Nextcloud" : "Nextcloud-ი",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP საიდუმლო გასაღების ლოგინით",
    "Share" : "გაზიარება",
    "Show hidden files" : "დამალული ფაილების ჩვენება",
    "Timeout" : "დრო ამოიწურა",
    "OpenStack Object Storage" : "OpenStack ობიექტ საცავი",
    "Service name" : "სერვისის სახელი",
    "Request timeout (seconds)" : "მოთხოვნის დროის ამოწურვა (წამები)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL-ის მხარდაჭერა PHP-ში არაა მოქდენი ან დაყენებული. %s-ის მონტაჟი ვერ ხერხდება. გთხოვთ სთხოვოთ თქვენი სისტემის ადმინისტრატორს მისი დაყენება.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP-ს მხარდაჭერა PHP-ში არაა მოქმედი ან დაყენებული. %s-ის მონტაჟი ვერ ხერხდება. გთხოვთ სთხოვოთ თქვენი სისტემის ადმინისტრატორს მისი დაყენება.",
    "External storage" : "ექსტერნალური საცავი",
    "External storage support" : "გარე საცავის მხარდაჭერა",
    "Confirm" : "დადასტურება",
    "External mount error" : "გარე მონტაჟის შეცდომა",
    "Storage type" : "საცავის სახეობა",
    "Unknown" : "უცნობია",
    "Scope" : "ფარგლები",
    "Personal" : "პირადი",
    "System" : "სისტემა",
    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD-სთან თავსებადობა (ნელი)",
    "Enable encryption" : "შიფრაციის ამოქმედება",
    "Enable previews" : "პრევიუების ამოქმედება",
    "Enable sharing" : "გაზიარების ამოქმედება",
    "Check for changes" : "ცვლილებების შემოწმება",
    "Never" : "არასდროს",
    "Once every direct access" : "ყოველთვის პირდაპირი წვდომისას",
    "Read only" : "მხოლოდ-კითხვადი",
    "Disconnect" : "კავშირის გაწყვეტა",
    "Admin defined" : "განსაზღვრულია ადმინისტრატორის მიერ",
    "Delete storage?" : "გავაუქმოთ საცავი?",
    "Click to recheck the configuration" : "დააწკაპუნეთ კონფიგურაციის ხელახალი შემოწმებისთვის",
    "Saved" : "შენახულია",
    "Save" : "შენახვა",
    "No external storage configured or you don't have the permission to configure them" : "გარე საცავი არაა კონფიგურირებული, ან არ გაქვთ უფლება გაუწიოთ მას კონფიგურაცია",
    "Open documentation" : "ღია დოკუმენტაცია",
    "Folder name" : "დირექტორიის სახელი",
    "Authentication" : "აუტენტიფიკაცია",
    "Configuration" : "კონფიგურაცია",
    "Available for" : "ხელმისაწვდომია რომ",
    "Add storage" : "საცავის დამატება",
    "Advanced settings" : "დამატებითი პარამეტრები"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/ka_GE.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "წვდომის მინიჭება",
    "Error configuring OAuth2" : "OAuth2-ის კონფიგურირებისას წარმოიშვა შეცდომა",
    "Generate keys" : "გასაღებების გენერირება",
    "Error generating key pair" : "გასაღების წყვილის გენერირებისას წარმოიშვა შეცდომა",
    "Storage with ID \"%d\" not found" : "საცავი ID-ით \"%d\" ვერ იქნა ნაპოვნი",
    "Invalid backend or authentication mechanism class" : "არასწორი ბექენდი ან აუტენტიფიკაციის მექანიზმის კლასი",
    "Invalid mount point" : "არასწორი მონტაჟის წერტილი",
    "Objectstore forbidden" : "ობიექტსტორი აკრძალულია",
    "Invalid storage backend \"%s\"" : "არასწორი საცავის ბექენდი \"%s\"",
    "Not permitted to use backend \"%s\"" : "ბექენის \"%s\" გამოყენება არაა ნებადართული",
    "Not permitted to use authentication mechanism \"%s\"" : "აუტენტიკაციის მექანიზმის \"%s\"-ს გამოყენება არაა ნებადართული",
    "Unsatisfied backend parameters" : "ბექენდის პარამეტრები არადამაკმაყოფილებელია",
    "Unsatisfied authentication mechanism parameters" : "აუტენტიფიკაციის მექნიზმის პარამეტრები არადამაკმაყოფილებელია",
    "Insufficient data: %s" : "არასაკმარისი მონაცემები: %s",
    "%s" : "%s",
    "Access key" : "წვდომის გასაღები",
    "Secret key" : "საიდუმლო გასაღები",
    "Builtin" : "ჩაშენებული",
    "None" : "არც ერთი",
    "OAuth2" : "OAuth2",
    "Client ID" : "კლიენტის ID",
    "Client secret" : "კლიენტის საიდუმლო",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "ავტორიზაცია",
    "Password" : "პაროლი",
    "Tenant name" : "მოიჯარის სახელი",
    "Identity endpoint URL" : "იდენტობის საბოლოო-წერტილის URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "დომენი",
    "Rackspace" : "Rackspace-ი",
    "API key" : "API გასაღები",
    "Global credentials" : "გლობალური მონაცემები",
    "Log-in credentials, save in database" : "ლოგინის მონაცემები, შენახვა მონაცემთა ბაზაში",
    "Log-in credentials, save in session" : "ლოგინის მონაცემები, შენახვა სესიაში",
    "RSA public key" : "RSA ღია გასაღები",
    "Public key" : "ღია გასაღები",
    "Bucket" : "ხაპია",
    "Hostname" : "ჰოსტი",
    "Port" : "პორტი",
    "Region" : "რეგიონი",
    "Enable SSL" : "SSL-ის ამოქმედება",
    "Enable Path Style" : "ბილიკის სტილის ამოქმედება",
    "Legacy (v2) authentication" : "ლეგატი (ვ2) აუტენტიფიკაცია",
    "WebDAV" : "WebDAV-ი",
    "URL" : "URL",
    "Remote subfolder" : "დისტანციური ქვე-დირექტორია",
    "Secure https://" : "დაცული https://",
    "FTP" : "FTP",
    "Host" : "ჰოსტი",
    "Secure ftps://" : "დაცული ftps://",
    "Local" : "ლოკალური",
    "Location" : "ადგილმდებარეობა",
    "Nextcloud" : "Nextcloud-ი",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP საიდუმლო გასაღების ლოგინით",
    "Share" : "გაზიარება",
    "Show hidden files" : "დამალული ფაილების ჩვენება",
    "Timeout" : "დრო ამოიწურა",
    "OpenStack Object Storage" : "OpenStack ობიექტ საცავი",
    "Service name" : "სერვისის სახელი",
    "Request timeout (seconds)" : "მოთხოვნის დროის ამოწურვა (წამები)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL-ის მხარდაჭერა PHP-ში არაა მოქდენი ან დაყენებული. %s-ის მონტაჟი ვერ ხერხდება. გთხოვთ სთხოვოთ თქვენი სისტემის ადმინისტრატორს მისი დაყენება.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP-ს მხარდაჭერა PHP-ში არაა მოქმედი ან დაყენებული. %s-ის მონტაჟი ვერ ხერხდება. გთხოვთ სთხოვოთ თქვენი სისტემის ადმინისტრატორს მისი დაყენება.",
    "External storage" : "ექსტერნალური საცავი",
    "External storage support" : "გარე საცავის მხარდაჭერა",
    "Confirm" : "დადასტურება",
    "External mount error" : "გარე მონტაჟის შეცდომა",
    "Storage type" : "საცავის სახეობა",
    "Unknown" : "უცნობია",
    "Scope" : "ფარგლები",
    "Personal" : "პირადი",
    "System" : "სისტემა",
    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD-სთან თავსებადობა (ნელი)",
    "Enable encryption" : "შიფრაციის ამოქმედება",
    "Enable previews" : "პრევიუების ამოქმედება",
    "Enable sharing" : "გაზიარების ამოქმედება",
    "Check for changes" : "ცვლილებების შემოწმება",
    "Never" : "არასდროს",
    "Once every direct access" : "ყოველთვის პირდაპირი წვდომისას",
    "Read only" : "მხოლოდ-კითხვადი",
    "Disconnect" : "კავშირის გაწყვეტა",
    "Admin defined" : "განსაზღვრულია ადმინისტრატორის მიერ",
    "Delete storage?" : "გავაუქმოთ საცავი?",
    "Click to recheck the configuration" : "დააწკაპუნეთ კონფიგურაციის ხელახალი შემოწმებისთვის",
    "Saved" : "შენახულია",
    "Save" : "შენახვა",
    "No external storage configured or you don't have the permission to configure them" : "გარე საცავი არაა კონფიგურირებული, ან არ გაქვთ უფლება გაუწიოთ მას კონფიგურაცია",
    "Open documentation" : "ღია დოკუმენტაცია",
    "Folder name" : "დირექტორიის სახელი",
    "Authentication" : "აუტენტიფიკაცია",
    "Configuration" : "კონფიგურაცია",
    "Available for" : "ხელმისაწვდომია რომ",
    "Add storage" : "საცავის დამატება",
    "Advanced settings" : "დამატებითი პარამეტრები",
    "Error configuring OAuth1" : "OAuth1-ის კონფიგურირებისას წარმოიშვა შეცდომა",
    "Please provide a valid app key and secret." : "გთხოვთ უზრუნველყოთ სწორი აპლიკაციის გასაღები და საიდუმლო.",
    "OAuth1" : "OAuth1",
    "App key" : "აპლიკაციის გასაღები",
    "App secret" : "აპლიკაციის საიდუმლო"
},
"nplurals=2; plural=(n!=1);");
